#!/usr/bin/env python
import platform
'''
ansi.py

ANSI Terminal Interface

(C)opyright 2000 Jason Petrone <jp_py@demonseed.net>
All Rights Reserved

Color Usage:
  print RED + 'this is red' + RESET
  print BOLD + GREEN + WHITEBG + 'this is bold green on white' + RESET

Commands:
  def move(new_x, new_y): 'Move cursor to new_x, new_y'
  def moveUp(lines): 'Move cursor up # of lines'
  def moveDown(lines): 'Move cursor down # of lines'
  def moveForward(chars): 'Move cursor forward # of chars'
  def moveBack(chars): 'Move cursor backward # of chars'
  def save(): 'Saves cursor position'
  def restore(): 'Restores cursor position'
  def clear(): 'Clears screen and homes cursor'
  def clrtoeol(): 'Clears screen to end of line'
'''

################################
# C O L O R  C O N S T A N T S #
################################
def ansiUnSupported():
	return platform.system()!="Linux"

def ansiSupported():
	return not ansiUnSupported()

BLACK = ansiSupported() and '\033[30m' or ''
RED = ansiSupported() and '\033[31m' or ''
GREEN = ansiSupported() and '\033[32m' or ''
YELLOW = ansiSupported() and '\033[33m' or ''
BLUE = ansiSupported() and '\033[34m' or ''
MAGENTA = ansiSupported() and '\033[35m' or ''
CYAN = ansiSupported() and '\033[36m' or ''
WHITE = ansiSupported() and '\033[37m' or ''

RESET = ansiSupported() and '\033[0;0m' or ''
BOLD = ansiSupported() and '\033[1m' or ''
REVERSE = ansiSupported() and '\033[2m' or ''

BLACKBG = ansiSupported() and '\033[40m' or ''
REDBG = ansiSupported() and '\033[41m' or ''
GREENBG = ansiSupported() and '\033[42m' or ''
YELLOWBG = ansiSupported() and '\033[43m' or ''
BLUEBG = ansiSupported() and '\033[44m' or ''
MAGENTABG = ansiSupported() and '\033[45m' or ''
CYANBG = ansiSupported() and '\033[46m' or ''
WHITEBG = ansiSupported() and '\033[47m' or ''

def move(new_x, new_y):
	'Move cursor to new_x, new_y'
	if ansiUnSupported(): return
	print '\033[' + str(new_x) + ';' + str(new_y) + 'H'

def moveUp(lines):
	'Move cursor up # of lines'
	if ansiUnSupported(): return
	print '\033[' + str(lines) + 'A'

def moveDown(lines):
	'Move cursor down # of lines'
	if ansiUnSupported(): return
	print '\033[' + str(lines) + 'B'

def moveForward(chars):
	'Move cursor forward # of chars'
	if ansiUnSupported(): return
	print '\033[' + str(lines) + 'C'

def moveBack(chars):
	'Move cursor backward # of chars'
	if ansiUnSupported(): return
	print '\033[' + str(lines) + 'D'

def save():
	'Saves cursor position'
	if ansiUnSupported(): return
	print '\033[s'

def restore():
	'Restores cursor position'
	if ansiUnSupported(): return
	print '\033[u'

def clear():
	'Clears screen and homes cursor'
	if ansiUnSupported(): return
	print '\033[2J'

def clrtoeol():
	'Clears screen to end of line'
	if ansiUnSupported(): return
	print '\033[K'
