#!/usr/bin/python
import os, sys

def getSourcePath():
	"""Return the directory where the program is located given sys.argv[0]"""
	return os.path.dirname( os.path.realpath(sys.argv[0]) )+"/"

def delrecurse(path):
	""" Delete a file or a directory recursively """
	print "Removing %s"%path
	if os.path.isdir(path):
		sub=os.listdir(path)
		for subfile in sub:
			delrecurse(subfile)
		os.rmdir(path)
	else:
		os.unlink(path)

def autoupdate(url, regex=None, targetpath=None):
	""" Given an url autoupdate:
		if the url is a zipfile download it to source directory and extract it inplace, if it's another type of file just download it inplace
		if regex the downloaded file will be searched for an url
		"""
	import urllib, urllib2, getpass, urlparse, re

	def writefile( filepath, content):
		""" Create a file with content, if the directory of file doesn't exists create it """
		filedir=os.path.split(filepath)[0]
		if not os.path.isdir(filedir):
			os.makedirs(filedir)

		f=file(filepath, "wb")
		f.write(content)
		f.close()

	def buildRequest(url):
		parts=list(urlparse.urlparse(url))
		parts[2]=urllib.quote(parts[2])
		url=urlparse.urlunparse(parts)
		req=urllib2.Request(url)

		user=getpass.getuser()
		agent="DkAutoUpdater - %s"%user

		req.add_header  ('User-agent', agent)
		return req

	print "Updating with %s."%url

	opener=urllib2.build_opener()

	req=buildRequest(url)
	data=opener.open(req)

	parsedurl=urlparse.urlparse(url)
	(dir,filename)=os.path.split(parsedurl[2])  #url relative to host
	destdir=getSourcePath()

	if regex:	#find some text and connect to first group of regex
		html=data.read()

		regsearch=re.search( regex, html )
		if not regsearch:
			raise Exception("Cannot find a link to the update.")

		relativenewpath=regsearch.groups()[0].strip()
		newurl=list(parsedurl)
		if relativenewpath[0]=="/":
			newurl[2]=relativenewpath	#absolute path with host
		else:
			newurl[2]=dir+relativenewpath	#relative path in host

		filename=os.path.split(relativenewpath)[1]
		if os.path.splitext(filename)[1] in (".zip",) and os.path.isfile(destdir+"autoupdate/"+filename):
			print "You already have the latest version: %s"%filename
			return

		newurl= urlparse.urlunparse(newurl)
		req=buildRequest(newurl)
		data=opener.open(req)


	if os.path.splitext(filename)[1] in (".zip",):
		if targetpath:
			destdir+=targetpath
			if destdir[-1]!="/": destdir+="/"
		else:
			destdir+="autoupdate/"
		dest=destdir+filename
		if not os.path.isdir(destdir):
			os.makedirs(destdir)

		print "Unzipping..."
		import glob
		for f in glob.glob(destdir+"*.zip"):
			os.unlink(f)
		f=file(dest,"wb")
		f.write( data.read() )
		f.close()
		import zipfile
		z=zipfile.ZipFile(dest)

		destdir=getSourcePath()
		for zf in z.infolist():
			writefile(destdir+zf.filename, z.read(zf.filename) )

	else:
		if targetpath and targetpath[-1]!="/": targetpath+="/"
		dest=destdir+targetpath+filename
		writefile(dest, data.read() )

	print "Update complete."


if __name__=="__main__":
	print "Autoupdater by Dario Varotto <dariosky@gmail.com>\n"
	#autoupdate("http://dariosky.local/messy.php",	r'<h2><a href="(.*)">versione: .*?</a></h2>')
